@@ -11,6 +11,7 @@ import (
 func TestParseLocalStorageBlock(t *testing.T) {
 	cases := []struct {
 		desc   string
+		env    map[string]string
 		source string
 		want   storage.Config
 		ok     bool
@@ -31,6 +32,25 @@ tfmigrate {
 			},
 			ok: true,
 		},
+		{
+			desc: "env vars",
+			env: map[string]string{
+				"VAR_NAME": "env1",
+			},
+			source: `
+tfmigrate {
+  history {
+    storage "local" {
+      path = "tmp/${env.VAR_NAME}/history.json"
+    }
+  }
+}
+`,
+			want: &local.Config{
+				Path: "tmp/env1/history.json",
+			},
+			ok: true,
+		},
 		{
 			desc: "missing required attribute (path)",
 			source: `
@@ -48,6 +68,9 @@ tfmigrate {
 
 	for _, tc := range cases {
 		t.Run(tc.desc, func(t *testing.T) {
+			for k, v := range tc.env {
+				t.Setenv(k, v)
+			}
 			config, err := ParseConfigurationFile("test.hcl", []byte(tc.source))
 			if tc.ok && err != nil {
 				t.Fatalf("unexpected err: %s", err)
